@@ -1,21 +1,9 @@
 /*
-  Copyright (C) 2002 Rik Hemsley (rikkus) <rik@kde.org>
-  Copyright (C) 2002 Benjamin Meyer <ben-devel@meyerhome.net>
-  Copyright (C) 2003 Richard Lärkäng <nouseforaname@home.se>
+    SPDX-FileCopyrightText: 2002 Rik Hemsley (rikkus) <rik@kde.org>
+    SPDX-FileCopyrightText: 2002 Benjamin Meyer <ben-devel@meyerhome.net>
+    SPDX-FileCopyrightText: 2003 Richard Lärkäng <nouseforaname@home.se>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kcmcddb.h"
@@ -26,8 +14,8 @@
 #include "libkcddb/cache.h"
 #include "libkcddb/submit.h"
 
-#include <KCoreAddons/KPluginFactory>
-#include <KWidgetsAddons/KMessageBox>
+#include <KPluginFactory>
+#include <KMessageBox>
 
 #include <QDebug>
 #include <QCheckBox>
